@@ -22,7 +22,7 @@ from pgamit import dbConnection, pyETM
 from pgamit.pyDate import Date
 from pgamit.pyLeastSquares import adjust_lsq
 from pgamit.pyOkada import ScoreTable
-from pgamit.Utils import (cart2euler, get_stack_stations, process_stnlist,
+from pgamit.Utils import (cart2euler, get_stack_stations, process_stnlist, add_version_argument,
                           stationID, file_write, xyz2sphere_lla, required_length, print_columns)
 
 
@@ -173,9 +173,10 @@ def analize_candidates(cnn, args):
             pt = folder_rejected.newpoint(name=stationID(stn), coords=[(stn['lon'], stn['lat'])])
             pt.stylemap = styles_nok
 
-        import cgi
-        import html
-        cgi.escape = html.escape
+        # DDG Jun 17 2025: the wrong version of simplekml was being used, now using latest
+        # import cgi
+        # import html
+        # cgi.escape = html.escape
 
         kml.savekmz(kmz_file + '.kmz')
 
@@ -541,6 +542,8 @@ def main():
                         as a kmz file (if filename given as 6th argument, do not 
                         include extension).''')
 
+    add_version_argument(parser)
+
     args = parser.parse_args()
 
     cnn = dbConnection.Cnn("gnss_data.cfg")
